%undefine _hardened_build

Name:           caml-crush
Version:        1.0.6
Release:        2%{?dist}
Summary:        PKCS#11 filtering proxy

# The pkcs11 bindings contain code under GPLv2+ which we don't use.
License:        MIT and FSFUL

URL:            https://github.com/ANSSI-FR/caml-crush
Source0:        caml-crush-%{version}.tar.gz
Source1:        filter.conf
Source2:        pkcs11proxyd.conf
Source3:        pkcs11proxyd-softhsm.service
Source4:        pkcs11proxyd-softhsm.module
Source5:        softhsm.conf
Source6:        pkcs11proxyd-softhsm-init
Source8:        pkcs11.conf
Source9:        softhsm.module
Source10:       pkcs11proxyd-softhsm.conf
Source11:       README.fedora
Source12:       filter-softhsm-locked.conf
Source13:       pkcs11proxyd-softhsm-ctl
Source14:	pkcs11proxyd-softhsm-ctl.8.txt
Patch4:         caml-crush-honor-CFLAGS.patch

Requires(pre):  shadow-utils
BuildRequires:  autoconf
BuildRequires:  ocaml >= 4.00
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-camlp4-devel
BuildRequires:  ocaml-camlidl-devel
BuildRequires:  coccinelle
BuildRequires:  ocaml-ocamlnet-devel
BuildRequires:  ocaml-config-file-devel
BuildRequires:  sed
BuildRequires:  p11-kit-devel
BuildRequires:  asciidoc
BuildRequires:  libxslt

%package softhsm

License:        MIT and FSFUL
Summary:        Deployment of caml-crush with softhsm

BuildRequires:	systemd

Requires: %{name}%{?_isa} = %{version}-%{release}
Requires:       softhsm
Requires:       inotify-tools
Requires:       util-linux
Requires:       p11-kit
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd

%global __provides_exclude_from ^%{_libdir}/pkcs11/.*\\.so$

%description
This software implements a PKCS#11 proxy as well as a PKCS#11 filter with
security features in mind.

%description softhsm
This software is a PKCS#11 proxy to softhsm allowing to store private keys
in an isolated environment in the system.

%prep
%setup -q -n %{name}-%{version}

%patch4 -p1 -b .cflags
sed -i 's|%LIBDIR%|'%{_libdir}'|g' %{SOURCE1}
sed -i 's|%LIBDIR%|'%{_libdir}'|g' %{SOURCE12}

cp %{SOURCE14} pkcs11proxyd-softhsm-ctl.8.txt
asciidoc.py -v -d manpage -b docbook pkcs11proxyd-softhsm-ctl.8.txt
xsltproc --nonet -o pkcs11proxyd-softhsm-ctl.8 /usr/share/asciidoc/docbook-xsl/manpage.xsl pkcs11proxyd-softhsm-ctl.8.xml

%build
sh autogen.sh
%configure \
  --datadir=%{_datadir}/%{name} \
  --with-rpcgen \
  --with-idlgen \
  --with-libnames=softhsm,'' \
  --with-client-socket="unix,/var/run/pkcs11proxyd.socket"

make

%pre
# replace any legacy names
getent group pkcs11proxyd &>/dev/null && \
	groupmod -n camlcrush pkcs11proxyd
getent passwd pkcs11proxyd &>/dev/null && \
	usermod -l camlcrush pkcs11proxyd
getent group camlcrush &>/dev/null || groupadd -r camlcrush
getent passwd camlcrush &>/dev/null || \
    /usr/sbin/useradd -r -g camlcrush -s /sbin/nologin -c camlcrush \
        -d %{_sharedstatedir}/pkcs11proxyd camlcrush
getent group pkcs11proxy &>/dev/null || groupadd -r pkcs11proxy

exit 0

%post
%systemd_post pkcs11proxyd-softhsm.service

%preun
%systemd_preun pkcs11proxyd-softhsm.service

%postun
%systemd_postun pkcs11proxyd-softhsm.service

%install
cp -a %{SOURCE11} README.fedora
mkdir -p %{buildroot}%{_sysconfdir}/pkcs11proxyd
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_libdir}/pkcs11
mkdir -p %{buildroot}%{_datadir}/p11-kit/modules
mkdir -p %{buildroot}%{_sharedstatedir}/pkcs11proxyd/.config/pkcs11/modules
mkdir -p %{buildroot}%{_mandir}/man8
install -p -m 755 src/pkcs11proxyd/pkcs11proxyd  %{buildroot}%{_sbindir}
install -p -m 755 src/client-lib/libp11clientsofthsm.so %{buildroot}%{_libdir}/pkcs11/
install -p -m 755 src/client-lib/libp11client.so %{buildroot}%{_libdir}/pkcs11/
install -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/pkcs11proxyd
install -p -m 644 %{SOURCE12} %{buildroot}%{_sharedstatedir}/pkcs11proxyd
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/pkcs11proxyd
install -p -m 644 %{SOURCE1} %{buildroot}%{_sharedstatedir}/pkcs11proxyd/filter-softhsm-unlocked.conf
install -p -m 644 %{SOURCE10} %{buildroot}%{_sysconfdir}/pkcs11proxyd/pkcs11proxyd-softhsm.conf
install -p -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/pkcs11proxyd-softhsm.service
install -p -m 644 %{SOURCE4} %{buildroot}/%{_datadir}/p11-kit/modules/
install -p -m 644 %{SOURCE5} %{buildroot}/%{_sharedstatedir}/pkcs11proxyd
install -p -m 755 %{SOURCE6} %{buildroot}%{_sbindir}/
install -p -m 644 %{SOURCE8} %{buildroot}%{_sharedstatedir}/pkcs11proxyd/.config/pkcs11/
install -p -m 644 %{SOURCE9} %{buildroot}%{_sharedstatedir}/pkcs11proxyd/.config/pkcs11/modules
install -p -m 755 %{SOURCE13} %{buildroot}%{_bindir}/
install -p -m 644 pkcs11proxyd-softhsm-ctl.8 %{buildroot}%{_mandir}/man8
ln -s %{_sharedstatedir}/pkcs11proxyd/filter-softhsm-unlocked.conf %{buildroot}%{_sysconfdir}/pkcs11proxyd/filter-softhsm.conf

%files
%doc README.md ISSUES.md README.fedora
%license LICENSE.txt
%{_libdir}/pkcs11/libp11client.so
%{_sbindir}/pkcs11proxyd

%dir %{_sysconfdir}/pkcs11proxyd
%config(noreplace) %{_sysconfdir}/pkcs11proxyd/filter.conf
%config(noreplace) %{_sysconfdir}/pkcs11proxyd/pkcs11proxyd.conf
%config(noreplace) %{_sysconfdir}/pkcs11proxyd/filter-softhsm.conf

%files softhsm
%{_sbindir}/pkcs11proxyd-softhsm-init
%{_bindir}/pkcs11proxyd-softhsm-ctl
%{_libdir}/pkcs11/libp11clientsofthsm.so
%{_unitdir}/pkcs11proxyd-softhsm.service

%{_datadir}/p11-kit/modules/pkcs11proxyd-softhsm.module

%{_sysconfdir}/pkcs11proxyd/pkcs11proxyd-softhsm.conf
%{_mandir}/man8/pkcs11proxyd-softhsm-ctl.8.gz

%defattr(-,camlcrush,camlcrush)
%dir %{_sharedstatedir}/pkcs11proxyd
%dir %{_sharedstatedir}/pkcs11proxyd/.config
%dir %{_sharedstatedir}/pkcs11proxyd/.config/pkcs11
%dir %{_sharedstatedir}/pkcs11proxyd/.config/pkcs11/modules
%{_sharedstatedir}/pkcs11proxyd/.config/pkcs11/modules/softhsm.module
%{_sharedstatedir}/pkcs11proxyd/.config/pkcs11/pkcs11.conf
%{_sharedstatedir}/pkcs11proxyd/softhsm.conf
%{_sharedstatedir}/pkcs11proxyd/filter-softhsm-locked.conf
%{_sharedstatedir}/pkcs11proxyd/filter-softhsm-unlocked.conf

%changelog
* Thu Jul 16 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 1.0.6-2
- Use a lexically distinct user and group name for internal access

* Mon Jun 22 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 1.0.6-1
- Updated to 1.0.6

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Thu Apr  2 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 1.0.4-6
- Added pkcs11proxyd-softhsm-ctl

* Wed Apr  1 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 1.0.4-5
- Removed default upstream filters and added documentation

* Mon Mar 23 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 1.0.4-4
- do not include the RSA's headers and GPLv3 code to simplify licensing

* Wed Mar 18 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 1.0.4-3
- utilize global CFLAGS - suggested by Petr Pisar

* Wed Mar 11 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 1.0.4-2
- removed unnecessary macros - suggested by Richard W.M. Jones
- added systemd dependency - suggested by Petr Pisar

* Mon Mar  9 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 1.0.4-1
- initial release
